from .basic import length , uppercase , lowercase , title , swapping_case , starts , spliting_lines , counting_char , finding , comparison , concatenate , copy , reverse , replace , capitalizes , multiply
from .advanced import isalphanumeric , isalphabets , isdigits , isuppers , islowers , isspaces , palindrome , pangram , anagram , alphaorder , char_to_ascii , dec_to_char




def length(s):
    count=0
    for i in range(len(s)):
        count=count+1
    return count

def uppercase(s):
    a=[]
    for i in range(len(s)):
        if (ord(s[i])>=97 and ord(s[i])<=122):
            a.append(chr(ord(s[i])-32))
        else:
            a.append(s[i])
    b=''.join(a)
    return str(b)

def lowercase(s):
    a=[]
    for i in range(len(s)):
        if (ord(s[i])>=65 and ord(s[i])<=90):
            a.append(chr(ord(s[i])+32))
        else:
            a.append(s[i])
    b=''.join(a)
    return str(b)

def title(s):
    count=0
    pos=[]
    for i in range(len(s)):
        if s[i]!=" " and s[i]!=".":
            count=count+1
        if s[i]==" " or s[i]==".":
            pos.append(count)
            count=count+1
    if ord(s[0])>=97 and ord(s[0])<=122:
        a=list(s)
        a[0]=chr(ord(s[0])-32)
        for i in range(len(pos)):
            a[pos[i]+1]=chr(ord(a[pos[i]+1])-32)
        b=''.join(a)
    if ord(s[0])>=65 and ord(s[0])<=90:
        a=list(s)
        for i in range(len(pos)):
            a[pos[i]+1]=chr(ord(a[pos[i]+1])-32)
        b=''.join(a)
    return b

def swapping_case(s):
    a=[]
    for i in range(len(s)):
        if (ord(s[i])>=97 and ord(s[i])<=122):
            a.append(chr(ord(s[i])-32))
        elif (ord(s[i])>=65 and ord(s[i])<=90):
            a.append(chr(ord(s[i])+32))
        else:
            a.append(s[i])
    a=''.join(a)
    return a

def starts(s,s1,pos):
    a=[]
    for i in range(len(s1)):
        a.append(s[pos])
        pos=pos+1
    b=''.join(a)
    if s1==b:
        return True
    else:
        return False

def spliting_lines(s):
    a=[]
    count=0
    for i in range(len(s)):
        if s[i]!=".":
            count=count+1
        if s[i]==".":
            a.append(count)
            count=count+1
    a.append(len(s))
    b=[]
    b.append(s[0:a[0]])
    for i in range(len(a)-1):
        b.append(s[a[i]+1:a[i+1]])
    if len(b)>1:
        while('' in b):
            b.remove('')
    return b

def counting_char(s,s1,start,end):
    count=0
    for i in range(len(s[start:end+1])):
        if s[i]==s1:
            count=count+1
    return count

def finding(s,s1,start,end):
    ss1=s[start:end+1]
    for i in range(len(ss1)):
        if ss1[i]==s1[0]:
            return i

def comparison(s,s1):
    if s==s1:
        return True
    else:
        return False

def concatenate(s,s1):
    a=[]
    a.append(s)
    for i in range(len(s1)):
        a.append(s1[i])
    b=''.join(a)
    return b

def copy(s):
    return s

def reverse(s):
    a=list(s)
    b=[]
    j=len(s)
    for i in range(len(s)):
        b.append(s[j-1])
        j=j-1
    b=''.join(b)
    return b

def replace(s,s1,s2):
    a=list(s)
    b=[]
    for i in range(len(s)):
        if s[i]==s1:
            b.append(i)
    for i in range(len(b)):
        a[b[i]]=s2
    c=''.join(a)
    return c

def capitalizes(s):
    a=list(s)
    if ord(a[0])>=65 and ord(a[0])<=90:
        pass
    if ord(a[0])>=97 and ord(a[0])<=122:
        a[0]=chr(ord(a[0])-32)
    a=''.join(a)
    return a

def multiply(s,n):
    a=[]
    for i in range(n):
        a.append(s)
    a=''.join(a)
    return a



def isalphanumeric(s):
    a=True
    for i in range(len(s)):
        if (ord(s[i])>=97 and ord(s[i])<=122) or (ord(s[i])>=65 and ord(s[i])<=90) or (ord(s[i])>=48 and ord(s[i])<=57):
            a=True
        else:
            a=False
    return a

def isalphabets(s):
    a=True
    for i in range(len(s)):
        if (ord(s[i])>=97 and ord(s[i])<=122) or (ord(s[i])>=65 and ord(s[i])<=90):
            a=True
        else:
            a=False
    return a

def isdigits(s):
    a=True
    for i in range(len(s)):
        if (ord(s[i])>=48 and ord(s[i])<=57):
            a=True
        else:
            a=False
    return a

def isuppers(s):
    a=True
    for i in range(len(s)):
        if (ord(s[i])>=65 and ord(s[i])<=90) or (ord(s[i])>=48 and ord(s[i])<=57) or (ord(s[i])>=32 and ord(s[i])<=47) or (ord(s[i])>=58 and ord(s[i])<=64) or (ord(s[i])>=91 and ord(s[i])<=96) or (ord(s[i])>=123 and ord(s[i])<=126):
            a=True
        else:
            a=False
    return a

def islowers(s):
    a=True
    for i in range(len(s)):
        if (ord(s[i])>=97 and ord(s[i])<=122) or (ord(s[i])>=48 and ord(s[i])<=57) or (ord(s[i])==32 and ord(s[i])<=47) or (ord(s[i])>=58 and ord(s[i])<=64) or (ord(s[i])>=91 and ord(s[i])<=96) or (ord(s[i])>=123 and ord(s[i])<=126):
            a=True
        else:
            a=False
    return a

def isspaces(s):
    a=True
    for i in range(len(s)):
        if (ord(s[i])==32):
            a=True
        else:
            a=False
    return a

def palindrome(s):
    b=[]
    j=len(s)-1
    for i in range(len(s)):
        b.append(s[j])
        j=j-1
    b=''.join(b)
    if s==b:
        return True
    else:
        return False

def pangram(s):
    s=s.lower()
    c=[]
    for i in s:
        if (i not in c) and (ord(i)>=97 and ord(i)<=122):
            c.append(i)
    if(len(c)==27 or len(c)==26):
        return True
    else:
        return False

def anagram(s,s1):
    a=[]
    b=[]
    for i in range(len(s)):
        a.append(ord(s[i]))
    for i in range(len(s1)):
        b.append(ord(s1[i]))
    if sum(a)==sum(b):
        return True
    else:
        return False
def alphaorder(s):
    a=[]
    b=[]
    for i in range(len(s)):
        a.append(ord(s[i]))
    a.sort()
    for i in range(len(s)):
        b.append(chr(a[i]))
    b=''.join(b)
    return b

def char_to_ascii(s):
    a=[]
    for i in range(len(s)):
        a.append(ord(s[i]))
    return a

def dec_to_char(s):
    a=[]
    for i in range(len(s)):
        a.append(chr(s[i]))
    a=''.join(a)
    return a



import setuptools

with open(r"C:\Users\Phanindra Thorati\mypackage\README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="stringsfuns",
    version="0.1",
    description="String functions",
    long_description=long_description,
    long_description_content_type='text/markdown',
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    author="Thorati Jai Satya Sai Phanindra",
    author_email="thoratiphanindra@gmail.com",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    zip_safe=False
)
